==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/actions/caret/GoRightAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.caret;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.measure.UndoableAddMeasure;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class GoRightAction extends Action{
    public static final String NAME = "GO_RIGHT";
    
    public GoRightAction(TablatureEditor tablatureEditor) {
        super(NAME,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        Caret caret = getEditor().getTablature().getCaret();
        if(!caret.moveRight()){         
            //comienza el undoable
        	UndoableAddMeasure undoable = UndoableAddMeasure.startUndo();
        	
        	getSongManager().addNewMeasureBeforeEnd();                	                            
        	fireUpdate(caret.getSongTrackCoords().getTrack().getMeasures().size(),true);        	
    	    caret.moveRight();
    	    
            //termia el undoable
    	    long undoablePosition = caret.getSongTrackCoords().getLastMeasure().getMeasure().getStart();
            getEditor().getUndoManager().addEdit(undoable.endUndo(undoablePosition));   	    
        }                                    
        redraw();    
        return true;
    }


}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/actions/caret/GoRightAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.caret;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.editors.TablatureEditor;
import org.herac.tuxguitar.gui.editors.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.measure.UndoableAddMeasure;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class GoRightAction extends Action{
    public static final String NAME = "action.caret.go-right";
    
    public GoRightAction(TablatureEditor tablatureEditor) {
        super(NAME,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        Caret caret = getEditor().getTablature().getCaret();
        if(!caret.moveRight()){         
        	int number = (getSongManager().countMeasures() + 1);
        	
            //comienza el undoable
        	UndoableAddMeasure undoable = UndoableAddMeasure.startUndo(number);         	
        	
        	getSongManager().addNewMeasure(number);
        	fireUpdate(number,true);        	
    	    caret.moveRight();
    	    
            //termia el undoable
            getEditor().getUndoManager().addEdit(undoable.endUndo());   	    
        }                                    
        redraw();    
        return true;
    }


}
